==> ktsuss_1.3.orig.tar.gz: ktsuss-1.3/src/errors.h <==
/* vim: set sw=4 sts=4 : */

/* Copyright (c) 2007-2008, David B. Cortarello
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   * Redistributions of source code must retain the above copyright notice
 *     and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above copyright notice
 *     and the following disclaimer in the documentation and/or other materials
 *     provided with the distribution.
 *   * Neither the name of Kwort nor the names of its contributors may be used
 *     to endorse or promote products derived from this software without
 *     specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
*/


#include "config.h"

enum {
	ERR_SUCCESS,
	ERR_OPEN_FILE_GROUP,
	ERR_FAILED_ADDITIONAL_GIDS,
	ERR_OPEN_FILE_PASSWD,
	ERR_INVALID_USERNAME,
	ERR_FAILED_CRYPT,
	ERR_WRONG_PASSWD,
	ERR_FAILED_SET_GID,
	ERR_FAILED_SET_UID,
	ERR_COMMAND_NOT_FOUND,
	ERR_PERMISSION_DENIED,
	ERR_MISSING_COMMAND,
	ERR_FAILED_SETUID,
	ERR_MISSING_USER_AND_COMMAND
};

static const char *KTS_ERRORS[] = {
    "Success",
	"Unable to open /etc/group",
	"Unable to set additional group IDs",
	"Unable to open /etc/passwd",
	"Invalid username",
	"Encryption failed",
	"Wrong password",
	"Unable to set group ID",
	"Unable to set user ID",
	"Command not found",
	"Permission denied",
	"No command given",
	"SetUID error",
	"No user and command specified"
};

==> ktsuss-1.4.tar.gz: ktsuss-1.4/src/errors.h <==
/* vim: set sw=4 sts=4 : */

/* Copyright (c) 2007-2008, David B. Cortarello
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   * Redistributions of source code must retain the above copyright notice
 *     and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above copyright notice
 *     and the following disclaimer in the documentation and/or other materials
 *     provided with the distribution.
 *   * Neither the name of Kwort nor the names of its contributors may be used
 *     to endorse or promote products derived from this software without
 *     specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
*/

#include "config.h"

enum {
	ERR_SUCCESS,
	ERR_OPEN_FILE_GROUP,
	ERR_FAILED_ADDITIONAL_GIDS,
	ERR_OPEN_FILE_PASSWD,
	ERR_INVALID_USERNAME,
	ERR_FAILED_CRYPT,
	ERR_WRONG_PASSWD,
	ERR_FAILED_SET_GID,
	ERR_FAILED_SET_UID,
	ERR_COMMAND_NOT_FOUND,
	ERR_PERMISSION_DENIED,
	ERR_MISSING_COMMAND,
	ERR_FAILED_SETUID,
	ERR_MISSING_USER_AND_COMMAND,
	ERR_MISSING_MESSAGE_AND_COMMAND
};

static const char *KTS_ERRORS[] = {
	"Success",
	"Unable to open /etc/group",
	"Unable to set additional group IDs",
	"Unable to open /etc/passwd",
	"Invalid username",
	"Encryption failed",
	"Wrong password",
	"Unable to set group ID",
	"Unable to set user ID",
	"Command not found",
	"Permission denied",
	"No command given",
	"SetUID error",
	"No user and command specified",
	"No message and command specified"
};
